@@ -110,6 +110,7 @@ class LpCsfFormValidatorMixin(
     CrfRequisitionFormValidatorMixin,
     LpFormValidatorMixin,
     QuantitativeCsfFormValidatorMixin,
+    CsfCultureFormValidatorMixin,
 ):
 
     requisition_fields = [
@@ -123,6 +124,8 @@ class LpCsfFormValidatorMixin(
 
         self.validate_quantitative_culture("qc_requisition")
 
+        self.validate_csf_culture()
+
 
 class LpCsfFormValidator(LpCsfFormValidatorMixin, FormValidator):
 
